import { GetColumnData } from 'drizzle-orm';
import { Param, Query, SQL, SQLWrapper } from 'drizzle-orm/sql';
import { Simplify } from 'drizzle-orm/utils';
import { SQLiteDialect } from '../dialect';
import { SelectFieldsOrdered, SelectResultFields, SQLiteSelectFields } from '../operations';
import { PreparedQuery, SQLiteSession } from '../session';
import { AnySQLiteTable, GetTableConfig, InferModel } from '../table';
export interface SQLiteUpdateConfig {
    where?: SQL | undefined;
    set: SQLiteUpdateSet;
    table: AnySQLiteTable;
    returning?: SelectFieldsOrdered;
}
export declare type SQLiteUpdateSetSource<TTable extends AnySQLiteTable> = Simplify<{
    [Key in keyof GetTableConfig<TTable, 'columns'>]?: GetColumnData<GetTableConfig<TTable, 'columns'>[Key], 'query'> | SQL;
}>;
export declare type SQLiteUpdateSet = Record<string, SQL | Param | null | undefined>;
export declare class SQLiteUpdateBuilder<TTable extends AnySQLiteTable, TResultType extends 'sync' | 'async', TRunResult> {
    protected table: TTable;
    protected session: SQLiteSession;
    protected dialect: SQLiteDialect;
    protected $table: TTable;
    constructor(table: TTable, session: SQLiteSession, dialect: SQLiteDialect);
    set(values: SQLiteUpdateSetSource<TTable>): SQLiteUpdate<TTable, TResultType, TRunResult>;
}
export interface SQLiteUpdate<TTable extends AnySQLiteTable, TResultType extends 'sync' | 'async', TRunResult, TReturning = undefined> extends SQLWrapper {
}
export declare class SQLiteUpdate<TTable extends AnySQLiteTable, TResultType extends 'sync' | 'async', TRunResult, TReturning = undefined> implements SQLWrapper {
    private session;
    private dialect;
    protected $table: TTable;
    private config;
    constructor(table: TTable, set: SQLiteUpdateSet, session: SQLiteSession, dialect: SQLiteDialect);
    where(where: SQL | undefined): Omit<this, 'where'>;
    returning(): Omit<SQLiteUpdate<TTable, TResultType, TRunResult, InferModel<TTable>>, 'where' | 'returning'>;
    returning<TSelectedFields extends SQLiteSelectFields>(fields: TSelectedFields): Omit<SQLiteUpdate<TTable, TResultType, TRunResult, SelectResultFields<TSelectedFields>>, 'where' | 'returning'>;
    toSQL(): Query;
    prepare(): PreparedQuery<{
        type: TResultType;
        run: TRunResult;
        all: TReturning extends undefined ? never : TReturning[];
        get: TReturning extends undefined ? never : TReturning;
        values: TReturning extends undefined ? never : any[][];
    }>;
    run: ReturnType<this['prepare']>['run'];
    all: ReturnType<this['prepare']>['all'];
    get: ReturnType<this['prepare']>['get'];
    values: ReturnType<this['prepare']>['values'];
}
